# Werkzeug

WSGI工具

## Usage

```
pip install Werkzeug

```

定义多路由：
```
from werkzeug.wrappers import Request, Response
from werkzeug.serving import run_simple
from werkzeug.routing import Map, Rule

# 定义路由处理函数
def hello_world(request):
    return Response('Hello, World!', content_type='text/plain')

def greet_user(request, username):
    return Response(f'Hello, {username}!', content_type='text/plain')

# 创建 URL 映射规则
url_map = Map([
    Rule('/', endpoint='hello_world'),
    Rule('/user/<username>', endpoint='greet_user')
])

# 创建应用程序
def application(environ, start_response):
    request = Request(environ)
    adapter = url_map.bind_to_environ(environ)
    endpoint, values = adapter.match()
    
    if endpoint == 'hello_world':
        response = hello_world(request)
    elif endpoint == 'greet_user':
        response = greet_user(request, values['username'])
    else:
        response = Response('Not Found', status=404)

    return response(environ, start_response)

# 运行 Web 服务器
if __name__ == '__main__':
    run_simple('localhost', 8080, application)

```